@@ -1,5 +1,6 @@
 "This sub-module provides formatting functions."
 import curses
+import sys
 
 _derivatives = ('on', 'bright', 'on_bright',)
 
@@ -15,8 +16,14 @@ COLORS = set(['_'.join((derivitive, color))
 #: All valid compoundable names.
 COMPOUNDABLES = (COLORS | _compoundables)
 
+if sys.version_info[0] == 3:
+    text_type = str
+    basestring = str
+else:
+    text_type = unicode  # noqa
 
-class ParameterizingString(unicode):
+
+class ParameterizingString(text_type):
     """A Unicode string which can be called as a parameterizing termcap.
 
     For example::
@@ -35,7 +42,7 @@ class ParameterizingString(unicode):
         :arg name: name of this terminal capability.
         """
         assert len(args) and len(args) < 4, args
-        new = unicode.__new__(cls, args[0])
+        new = text_type.__new__(cls, args[0])
         new._normal = len(args) > 1 and args[1] or u''
         new._name = len(args) > 2 and args[2] or u'<not specified>'
         return new
@@ -74,7 +81,7 @@ class ParameterizingString(unicode):
             return NullCallableString()
 
 
-class ParameterizingProxyString(unicode):
+class ParameterizingProxyString(text_type):
     """A Unicode string which can be called to proxy missing termcap entries.
 
     For example::
@@ -102,7 +109,7 @@ class ParameterizingProxyString(unicode):
         assert len(args) and len(args) < 4, args
         assert type(args[0]) is tuple, args[0]
         assert callable(args[0][1]), args[0][1]
-        new = unicode.__new__(cls, args[0][0])
+        new = text_type.__new__(cls, args[0][0])
         new._fmt_args = args[0][1]
         new._normal = len(args) > 1 and args[1] or u''
         new._name = len(args) > 2 and args[2] or u'<not specified>'
@@ -121,21 +128,33 @@ class ParameterizingProxyString(unicode):
 
 
 def get_proxy_string(term, attr):
-    """ Returns an instance of ParameterizingProxyString
-    for (some kinds) of terminals and attributes.
+    """ Proxy and return callable StringClass for proxied attributes.
+
+    We know that some kinds of terminal kinds support sequences that the
+    terminfo database often doesn't report -- such as the 'move_x' attribute
+    for terminal type 'screen', or 'hide_cursor' for 'ansi'.
+
+    Returns instance of ParameterizingProxyString or NullCallableString.
     """
-    if term._kind == 'screen' and attr in ('hpa', 'vpa'):
-        if attr == 'hpa':
-            fmt = u'\x1b[{0}G'
-        elif attr == 'vpa':
-            fmt = u'\x1b[{0}d'
-        fmt_arg = lambda *arg: (arg[0] + 1,)
-        return ParameterizingProxyString((fmt, fmt_arg),
-                                         term.normal, 'hpa')
-    return None
+    return {
+        'screen': {
+            # proxy move_x/move_y for 'screen' terminal type.
+            'hpa': ParameterizingProxyString(
+                (u'\x1b[{0}G', lambda *arg: (arg[0] + 1,)), term.normal, attr),
+            'vpa': ParameterizingProxyString(
+                (u'\x1b[{0}d', lambda *arg: (arg[0] + 1,)), term.normal, attr),
+        },
+        'ansi': {
+            # proxy show/hide cursor for 'ansi' terminal type.
+            'civis': ParameterizingProxyString(
+                (u'\x1b[?25l', lambda *arg: ()), term.normal, attr),
+            'cnorm': ParameterizingProxyString(
+                (u'\x1b[?25h', lambda *arg: ()), term.normal, attr),
+        }
+    }.get(term._kind, {}).get(attr, None)
 
 
-class FormattingString(unicode):
+class FormattingString(text_type):
     """A Unicode string which can be called using ``text``,
     returning a new string, ``attr`` + ``text`` + ``normal``::
 
@@ -150,7 +169,7 @@ class FormattingString(unicode):
         :arg normal: terminating sequence for this attribute.
         """
         assert 1 <= len(args) <= 2, args
-        new = unicode.__new__(cls, args[0])
+        new = text_type.__new__(cls, args[0])
         new._normal = len(args) > 1 and args[1] or u''
         return new
 
@@ -165,12 +184,12 @@ class FormattingString(unicode):
         return text
 
 
-class NullCallableString(unicode):
+class NullCallableString(text_type):
     """A dummy callable Unicode to stand in for ``FormattingString`` and
     ``ParameterizingString`` for terminals that cannot perform styling.
     """
     def __new__(cls):
-        new = unicode.__new__(cls, u'')
+        new = text_type.__new__(cls, u'')
         return new
 
     def __call__(self, *args):
@@ -292,8 +311,8 @@ def resolve_attribute(term, attr):
         return FormattingString(u''.join(resolution), term.normal)
     else:
         # and, for special terminals, such as 'screen', provide a Proxy
-        # ParameterizingString for attributes they do not claim to support, but
-        # actually do! (such as 'hpa' and 'vpa').
+        # ParameterizingString for attributes they do not claim to support,
+        # but actually do! (such as 'hpa' and 'vpa').
         proxy = get_proxy_string(term, term._sugar.get(attr, attr))
         if proxy is not None:
             return proxy
