@@ -11,6 +11,7 @@ import functools
 import textwrap
 import warnings
 import math
+import sys
 import re
 
 # 3rd-party
@@ -20,6 +21,11 @@ _BINTERM_UNSUPPORTED = ('kermit', 'avatar')
 _BINTERM_UNSUPPORTED_MSG = ('sequence-awareness for terminals emitting '
                             'binary-packed capabilities are not supported.')
 
+if sys.version_info[0] == 3:
+    text_type = str
+else:
+    text_type = unicode  # noqa
+
 
 def _merge_sequences(inp):
     """Merge a list of input sequence patterns for use in a regular expression.
@@ -221,7 +227,7 @@ def get_wontmove_sequence_patterns(term):
         # ( not *exactly* legal, being extra forgiving. )
         bna(cap='sgr', nparams=_num) for _num in range(1, 10)
         # reset_{1,2,3}string: Reset string
-    ] + map(re.escape, (term.r1, term.r2, term.r3,)))
+    ] + list(map(re.escape, (term.r1, term.r2, term.r3,))))
 
 
 def init_sequence_patterns(term):
@@ -366,7 +372,7 @@ class SequenceTextWrapper(textwrap.TextWrapper):
 SequenceTextWrapper.__doc__ = textwrap.TextWrapper.__doc__
 
 
-class Sequence(unicode):
+class Sequence(text_type):
     """
     This unicode-derived class understands the effect of escape sequences
     of printable length, allowing a properly implemented .rjust(), .ljust(),
@@ -379,7 +385,7 @@ class Sequence(unicode):
         :arg sequence_text: A string containing sequences.
         :arg term: Terminal instance this string was created with.
         """
-        new = unicode.__new__(cls, sequence_text)
+        new = text_type.__new__(cls, sequence_text)
         new._term = term
         return new
 
@@ -518,7 +524,7 @@ class Sequence(unicode):
         """
         outp = u''
         nxt = 0
-        for idx in range(0, unicode.__len__(self)):
+        for idx in range(0, text_type.__len__(self)):
             width = horizontal_distance(self[idx:], self._term)
             if width != 0:
                 nxt = idx + measure_length(self[idx:], self._term)
