@@ -4,6 +4,38 @@ import curses
 import mock
 
 
+def test_parameterizing_string_args_unspecified(monkeypatch):
+    """Test default args of formatters.ParameterizingString."""
+    from blessed.formatters import ParameterizingString, FormattingString
+    # first argument to tparm() is the sequence name, returned as-is;
+    # subsequent arguments are usually Integers.
+    tparm = lambda *args: u'~'.join(
+        arg.decode('latin1') if not num else '%s' % (arg,)
+        for num, arg in enumerate(args)).encode('latin1')
+
+    monkeypatch.setattr(curses, 'tparm', tparm)
+
+    # given,
+    pstr = ParameterizingString(u'')
+
+    # excersize __new__
+    assert str(pstr) == u''
+    assert pstr._normal == u''
+    assert pstr._name == u'<not specified>'
+
+    # excersize __call__
+    zero = pstr(0)
+    assert type(zero) is FormattingString
+    assert zero == u'~0'
+    assert zero('text') == u'~0text'
+
+    # excersize __call__ with multiple args
+    onetwo = pstr(1, 2)
+    assert type(onetwo) is FormattingString
+    assert onetwo == u'~1~2'
+    assert onetwo('text') == u'~1~2text'
+
+
 def test_parameterizing_string_args(monkeypatch):
     """Test basic formatters.ParameterizingString."""
     from blessed.formatters import ParameterizingString, FormattingString
@@ -17,24 +49,24 @@ def test_parameterizing_string_args(monkeypatch):
     monkeypatch.setattr(curses, 'tparm', tparm)
 
     # given,
-    pstr = ParameterizingString(u'seqname', u'norm', u'cap-name')
+    pstr = ParameterizingString(u'cap', u'norm', u'seq-name')
 
     # excersize __new__
-    assert pstr._name == u'cap-name'
+    assert str(pstr) == u'cap'
     assert pstr._normal == u'norm'
-    assert str(pstr) == u'seqname'
+    assert pstr._name == u'seq-name'
 
     # excersize __call__
     zero = pstr(0)
     assert type(zero) is FormattingString
-    assert zero == u'seqname~0'
-    assert zero('text') == u'seqname~0textnorm'
+    assert zero == u'cap~0'
+    assert zero('text') == u'cap~0textnorm'
 
     # excersize __call__ with multiple args
     onetwo = pstr(1, 2)
     assert type(onetwo) is FormattingString
-    assert onetwo == u'seqname~1~2'
-    assert onetwo('text') == u'seqname~1~2textnorm'
+    assert onetwo == u'cap~1~2'
+    assert onetwo('text') == u'cap~1~2textnorm'
 
 
 def test_parameterizing_string_type_error(monkeypatch):
@@ -47,13 +79,13 @@ def test_parameterizing_string_type_error(monkeypatch):
     monkeypatch.setattr(curses, 'tparm', tparm_raises_TypeError)
 
     # given,
-    pstr = ParameterizingString(u'seqname', u'norm', u'cap-name')
+    pstr = ParameterizingString(u'cap', u'norm', u'cap-name')
 
     # ensure TypeError when given a string raises custom exception
     try:
         pstr('XYZ')
         assert False, "previous call should have raised TypeError"
-    except TypeError, err:
+    except TypeError as err:
         assert (err.args[0] == (  # py3x
             "A native or nonexistent capability template, "
             "'cap-name' received invalid argument ('XYZ',): "
@@ -69,7 +101,7 @@ def test_parameterizing_string_type_error(monkeypatch):
     try:
         pstr(0)
         assert False, "previous call should have raised TypeError"
-    except TypeError, err:
+    except TypeError as err:
         assert err.args[0] == "custom_err"
 
 
@@ -132,13 +164,22 @@ def test_resolve_capability(monkeypatch):
     assert resolve_capability(term, 'mnemonic') == u'seq-xyz'
     assert resolve_capability(term, 'natural') == u'seq-natural'
 
-    # given, always returns None
+    # given, where tigetstr returns None
     tigetstr_none = lambda attr: None
     monkeypatch.setattr(curses, 'tigetstr', tigetstr_none)
 
     # excersize,
     assert resolve_capability(term, 'natural') == u''
 
+    # given, where does_styling is False
+    def raises_exception(*args):
+        assert False, "Should not be called"
+    term.does_styling = False
+    monkeypatch.setattr(curses, 'tigetstr', raises_exception)
+
+    # excersize,
+    assert resolve_capability(term, 'natural') == u''
+
 
 def test_resolve_color(monkeypatch):
     """Test formatters.resolve_color."""
